@@ -16,6 +16,14 @@ try:
     if auto_start_global():
         GlobalRegistry.start()
         atexit.register(GlobalRegistry.stop)
+        try:
+            from os import register_at_fork
+            register_at_fork(before=GlobalRegistry.stop_without_publish,
+                             after_in_parent=GlobalRegistry.start,
+                             after_in_child=GlobalRegistry.clear_meters_and_start)
+        except ImportError:
+            pass
+
     else:
         logger.debug("module spectatorconfig auto-start is disabled - GlobalRegistry will not start")
 except ImportError:
